;/*****************************/;
;/* CP-JR6811 Example Program */;
;/* --> PortC Control SMCC-V2 */;
;/* --> Bipolar Step Motor    */;
;/* --> Single Chip Mode Run  */;
;/*****************************/;
;/* PC0 = EN1
;/* PC1 = EN2
;/* PC2 = INA
;/* PC3 = INB
;/* PC5 = INC
;/* PC6 = IND
;/* Assembler : AS11NEW

            ORG     $00
STEP_CNT:   RMB     1
CYCLECNT:   RMB     1
STEP_INX:   RMB     1

            ORG     $F800
MAIN        LDS     #$FF                    ; Set Stack Pointer
            LDAA    #$FF
            STAA    $1007                   ; Port-C = Output
            ;
HALF_DRV:   LDAA    #30
            STAA    CYCLECNT
HALF0:      LDAA    #8
            STAA    STEP_CNT                ; 8 Step/1 Cycle Counter
            LDAA    #0
            STAA    STEP_INX
HALF1:      LDX     #TAB_HALF1              ; Half Step Drive Table
            JSR     OUT_STEP                ; Out Signal Drive
            JSR     DLY10MS                 ; Delay For Next Step
            INC     STEP_INX                ; Next Step
            DEC     STEP_CNT
            BNE     HALF1
            DEC     CYCLECNT
            BNE     HALF0
            ;
            PSHB                            ; Delay Before Reverse Direction
            LDAB    #100
DLY_ON:     JSR     DLY10MS
            DECB
            BNE     DLY_ON
            PULB
            ;
            LDAA    #30
            STAA    CYCLECNT
HALF2:      LDAA    #8
            STAA    STEP_CNT                ; 8 Step/1 Cycle Counter
            LDAA    #0
            STAA    STEP_INX
HALF3:      LDX     #TAB_HALF2              ; Half Step Drive Table
            JSR     OUT_STEP                ; Out Signal Drive
            JSR     DLY10MS                 ; Delay For Next Step
            INC     STEP_INX                ; Next Step
            DEC     STEP_CNT
            BNE     HALF3
            DEC     CYCLECNT
            BNE     HALF2
            ;
            PSHB                            ; Delay Before Reverse Direction
            LDAB    #100
DLY_OFF:    JSR     DLY10MS
            DECB
            BNE     DLY_OFF
            PULB
            JMP     HALF_DRV                ; Loop Continue

;/********************************/;
;/* Out Stepp Motor Signal Drive */;
;/* Input  : INX  = Table Signal */;
;/*        : Step Index          */;
;/* Output : PortC Signal        */;
;/********************************/;
;
OUT_STEP:   LDAB    STEP_INX
            ABX
            LDAA    0,X                     ; Get Signal
            STAA    $1003                   ; PortC
            RTS

;/***********************/;
;/*  Delay Time 10 mSec */;
;/***********************/;
;
DLY10MS     PSHX
            LDX     #$0D06                  ; 10 mSec counter
DLY10       DEX
            BNE     DLY10
            PULX
            RTS

;/**********************/;
;/* Wave-Drive         */;
;/* Half Drive         */;
;/* ONE-Phase-ON Drive */;
;/* ONE-Excitation     */;
;/* 00,D,C,B,A,EN2,EN1 */;
;/* D7..............D0 */;
;/**********************/;
;
TAB_WAVE1:  FCB     00100010B               ; Step-2
            FCB     00000101B               ; Step-4
            FCB     00010010B               ; Step-6
            FCB     00001001B               ; Step-8
            FCB     00100010B               ; Step-2
            FCB     00000101B               ; Step-4
            FCB     00010010B               ; Step-6
            FCB     00001001B               ; Step-8
            ;
TAB_WAVE2:  FCB     00001001B               ; Step-8
            FCB     00010010B               ; Step-6
            FCB     00000101B               ; Step-4
            FCB     00100010B               ; Step-2
            FCB     00001001B               ; Step-8
            FCB     00010010B               ; Step-6
            FCB     00000101B               ; Step-4
            FCB     00100010B               ; Step-2

;/**********************/;
;/* Half Step Drive    */;
;/* ONE-TWO-Excitation */;
;/* 00,D,C,B,A,EN2,EN1 */;
;/* D7..............D0 */;
;/**********************/;
;
TAB_HALF1:  FCB     00101011B               ; Step-1
            FCB     00100010B               ; Step-2
            FCB     00100111B               ; Step-3
            FCB     00000101B               ; Step-4
            FCB     00010111B               ; Step-5
            FCB     00010010B               ; Step-6
            FCB     00011011B               ; Step-7
            FCB     00001001B               ; Step-8
            ;
TAB_HALF2:  FCB     00001001B               ; Step-8
            FCB     00011011B               ; Step-7
            FCB     00010010B               ; Step-6
            FCB     00010111B               ; Step-5
            FCB     00000101B               ; Step-4
            FCB     00100111B               ; Step-3
            FCB     00100010B               ; Step-2
            FCB     00101011B               ; Step-1
            
;/**********************/;
;/* TWO-Phase-ON Drive */;
;/* Normal-Drive       */;
;/* Full Step          */;
;/* TWO-Excitation     */;
;/* 00,D,C,B,A,EN2,EN1 */;
;/* D7..............D0 */;
;/**********************/;
;
TAB_FULL1:  FCB     00101011B               ; Step-1
            FCB     00100111B               ; Step-3
            FCB     00010111B               ; Step-5
            FCB     00011011B               ; Step-7
            FCB     00101011B               ; Step-1
            FCB     00100111B               ; Step-3
            FCB     00010111B               ; Step-5
            FCB     00011011B               ; Step-7
            ;
TAB_FULL2:  FCB     00011011B               ; Step-7
            FCB     00010111B               ; Step-5
            FCB     00100111B               ; Step-3
            FCB     00101011B               ; Step-1
            FCB     00011011B               ; Step-7
            FCB     00010111B               ; Step-5
            FCB     00100111B               ; Step-3
            FCB     00101011B               ; Step-1

            ORG     $FFFE
            FDB     MAIN

            END

