;/*************************************/;
;/* Example Program AT89C2051 Port-P1 */;
;/*   Bipolar Stepping Motor Control  */;
;/* Hardware : ET-CP2051 V2.0         */;
;/* Complier : SXA51                  */;
;/*************************************/;
;/*=>Motor1 : EN1,EN2,INA,INB,INC,IND */;
;/*  Signal : P10,P11,P12,P13,P14,P15 */;
;/*************************************/;

            ORG     20H
STEP_CNT:   DS      1
CYCLECNT:   DS      1
STEP_INX:   DS      1
STACK:      DS      32

            ORG     0000H
MAIN:       MOV     SP,#STACK               ; Stack 32 Byte
            MOV     R2,#02H                 ; Power-on Delay
PWR_DLY1:   MOV     R3,#00H
PWR_DLY2:   MOV     R4,#00H
            DJNZ    R4,$
            DJNZ    R3,PWR_DLY2
            DJNZ    R2,PWR_DLY1
            ;
HALF_DRV:   MOV     CYCLECNT,#50
HALF0:      MOV     STEP_CNT,#8             ; 8 Step/1 Cycle Counter
            MOV     STEP_INX,#0
HALF1:      MOV     DPTR,#TAB_HALF1         ; Half Step Drive Table
            MOV     A,STEP_INX
            MOVC    A,@A+DPTR               ; Get Signal
            MOV     P1,A                    ; Out Signal Drive
            LCALL   DELAY                   ; Delay For Next Step
            INC     STEP_INX                ; Next Step
            DJNZ    STEP_CNT,HALF1
            DJNZ    CYCLECNT,HALF0
            ;
            MOV     P1,#00H
            ;
            MOV     R3,#20                  ; Delay For Next Cycle
HALF_DL1:   MOV     R4,#00H
HALF_DL2:   MOV     R5,#00H
            DJNZ    R5,$
            DJNZ    R4,HALF_DL2
            DJNZ    R3,HALF_DL1
            ;
            MOV     CYCLECNT,#50
HALF2:      MOV     STEP_CNT,#8             ; 8 Step/1 Cycle Counter
            MOV     STEP_INX,#0
HALF3:      MOV     DPTR,#TAB_HALF2         ; Half Step Drive Table
            MOV     A,STEP_INX
            MOVC    A,@A+DPTR               ; Get Signal
            MOV     P1,A                    ; Out Signal Drive
            LCALL   DELAY                   ; Delay For Next Step
            INC     STEP_INX                ; Next Step
            DJNZ    STEP_CNT,HALF3
            DJNZ    CYCLECNT,HALF2
            ;
            MOV     P1,#00H
            ;
            MOV     R3,#20                  ; Delay For Next Cycle
HALF_DL3:   MOV     R4,#00H
HALF_DL4:   MOV     R5,#00H
            DJNZ    R5,$
            DJNZ    R4,HALF_DL4
            DJNZ    R3,HALF_DL3
            LJMP    HALF_DRV                ; Loop Continue

;/**********************/;
;/* Wave-Drive         */;
;/* Half Drive         */;
;/* ONE-Phase-ON Drive */;
;/* ONE-Excitation     */;
;/* 00,D,C,B,A,EN2,EN1 */;
;/* D7..............D0 */;
;/**********************/;
;
TAB_WAVE1:  DB      00100010B               ; Step-2
            DB      00000101B               ; Step-4
            DB      00010010B               ; Step-6
            DB      00001001B               ; Step-8
            DB      00100010B               ; Step-2
            DB      00000101B               ; Step-4
            DB      00010010B               ; Step-6
            DB      00001001B               ; Step-8
            ;
TAB_WAVE2:  DB      00001001B               ; Step-8
            DB      00010010B               ; Step-6
            DB      00000101B               ; Step-4
            DB      00100010B               ; Step-2
            DB      00001001B               ; Step-8
            DB      00010010B               ; Step-6
            DB      00000101B               ; Step-4
            DB      00100010B               ; Step-2

;/**********************/;
;/* Half Step Drive    */;
;/* ONE-TWO-Excitation */;
;/* 00,D,C,B,A,EN2,EN1 */;
;/* D7..............D0 */;
;/**********************/;
;
TAB_HALF1:  DB      00101011B               ; Step-1
            DB      00100010B               ; Step-2
            DB      00100111B               ; Step-3
            DB      00000101B               ; Step-4
            DB      00010111B               ; Step-5
            DB      00010010B               ; Step-6
            DB      00011011B               ; Step-7
            DB      00001001B               ; Step-8
            ;
TAB_HALF2:  DB      00001001B               ; Step-8
            DB      00011011B               ; Step-7
            DB      00010010B               ; Step-6
            DB      00010111B               ; Step-5
            DB      00000101B               ; Step-4
            DB      00100111B               ; Step-3
            DB      00100010B               ; Step-2
            DB      00101011B               ; Step-1
            
;/**********************/;
;/* TWO-Phase-ON Drive */;
;/* Normal-Drive       */;
;/* Full Step          */;
;/* TWO-Excitation     */;
;/* 00,D,C,B,A,EN2,EN1 */;
;/* D7..............D0 */;
;/**********************/;
;
TAB_FULL1:  DB      00101011B               ; Step-1
            DB      00100111B               ; Step-3
            DB      00010111B               ; Step-5
            DB      00011011B               ; Step-7
            DB      00101011B               ; Step-1
            DB      00100111B               ; Step-3
            DB      00010111B               ; Step-5
            DB      00011011B               ; Step-7
            ;
TAB_FULL2:  DB      00011011B               ; Step-7
            DB      00010111B               ; Step-5
            DB      00100111B               ; Step-3
            DB      00101011B               ; Step-1
            DB      00011011B               ; Step-7
            DB      00010111B               ; Step-5
            DB      00100111B               ; Step-3
            DB      00101011B               ; Step-1

;/**************/;
;/* Delay Time */;
;/**************/;
;
DELAY:      MOV     R4,#50
DLY1:       MOV     R5,#00H
            DJNZ    R5,$
            DJNZ    R4,DLY1
            RET

            END

