;/*************************************/;
;/* Example Program Z180 & 8255 Port  */;
;/*   Bipolar Stepping Motor Control  */;
;/* Hardware : ET-CPJR180 PLUS (R1)   */;
;/* Complier : CROSS-32 V4.0          */;
;/*************************************/;
;/*=>Motor1 : EN1,EN2,INA,INB,INC,IND */;
;/*  Signal : PA0,PA1,PA2,PA3,PA4,PA5 */;
;/*=>Motor2 : EN1,EN2,INA,INB,INC,IND */;
;/*  Signal : PA6,PA7,PB0,PB1,PB2,PB3 */;
;/*=>Motor3 : EN1,EN2,INA,INB,INC,IND */;
;/*  Signal : PB4,PB5,PB6,PB7,PC0,PC1 */;
;/*=>Motor4 : EN1,EN2,INA,INB,INC,IND */;
;/*  Signal : PC2,PC3,PC4,PC5,PC6,PC7 */;
;/*************************************/;

            CPU     "Z180.TBL"
            HOF     "INT8"

PA:         EQU     80H                     ; Port PA of 8255
PB:         EQU     81H                     ; Port PB of 8255
PC:         EQU     82H                     ; Port PC of 8255
PCC:        EQU     83H                     ; Control Port 8255

            ORG     8000H
START:      ;LD      SP,9FFFH                ; Stack pointer
            LD      HL,0000H                ; Power on delay
PWR1:       DEC     HL
            LD      A,H
            OR      L
            JR      NZ,PWR1         
            ;
            LD      A,80H                   ; PA,PB,PC=OP
            OUT     (PCC),A
            ;
;/********************/;
;/* Half Step Driver */;
;/********************/;
;
HALF_DRV:   LD      B,50
HALF0:      LD      A,8
            LD      (STEP_CNT),A            ; 8 Step/1 Cycle Counter
            LD      A,0
            LD      (STEP_INX),A
HALF1:      LD      HL,TAB_HALF1            ; Half Step Drive Table
            CALL    OUT_STEP                ; Out Signal Drive
            CALL    DELAY                   ; Delay For Next Step
            LD      HL,STEP_INX
            INC     (HL)                    ; Next Step
            LD      HL,STEP_CNT
            DEC     (HL)
            LD      A,(HL)
            JR      NZ,HALF1
            DJNZ    HALF0
            ;
            LD      A,0                     ; off motor
            OUT     (PA),A                  ; Out Signal
            OUT     (PB),A
            OUT     (PC),A
            ;
            PUSH    AF
            PUSH    HL
            LD      HL,0000H
HALF_DL1:   DEC     HL
            LD      A,H
            OR      L
            JR      NZ,HALF_DL1
            LD      HL,0000H
HALF_DL2:   DEC     HL
            LD      A,H
            OR      L
            JR      NZ,HALF_DL2
            LD      HL,0000H
HALF_DL3:   DEC     HL
            LD      A,H
            OR      L
            JR      NZ,HALF_DL3
            POP     HL
            POP     AF
            ;
            LD      B,50
HALF2:      LD      A,8
            LD      (STEP_CNT),A            ; 8 Step/1 Cycle Counter
            LD      A,0
            LD      (STEP_INX),A
HALF3:      LD      HL,TAB_HALF2            ; Half Step Drive Table
            CALL    OUT_STEP                ; Out Signal Drive
            CALL    DELAY                   ; Delay For Next Step
            LD      HL,STEP_INX
            INC     (HL)                    ; Next Step
            LD      HL,STEP_CNT
            DEC     (HL)
            LD      A,(HL)
            JR      NZ,HALF3
            DJNZ    HALF2
            ;
            LD      A,0                     ; off motor
            OUT     (PA),A                  ; Out Signal
            OUT     (PB),A
            OUT     (PC),A
            ;
            PUSH    AF
            PUSH    HL
            LD      HL,0000H
HALF_DL4:   DEC     HL
            LD      A,H
            OR      L
            JR      NZ,HALF_DL4
            LD      HL,0000H
HALF_DL5:   DEC     HL
            LD      A,H
            OR      L
            JR      NZ,HALF_DL5
            LD      HL,0000H
HALF_DL6:   DEC     HL
            LD      A,H
            OR      L
            JR      NZ,HALF_DL6
            POP     HL
            POP     AF
            JP      HALF_DRV

;/********************************/;
;/* Out Stepp Motor Signal Drive */;
;/* Input  : DPTR = Table Signal */;
;/*        : ACC  = Step Index   */;
;/* Output : Out Port8255 Signal */;
;/********************************/;
;
OUT_STEP:   PUSH    AF                      ; Save Register
            PUSH    BC
            PUSH    DE
            PUSH    HL
            LD      A,0                     ; Clear old Data
            LD      (PA_BUFF),A
            LD      (PB_BUFF),A
            LD      (PC_BUFF),A
            LD      B,0
            LD      A,(STEP_INX)
            LD      C,A
            ADD     HL,BC
            LD      A,(HL)                  ; Get Signal
            LD      (PA_BUFF),A             ; X,X,D,C,B,A,EN2,EN1 (Motor1)
            LD      B,A                     ;/* Save ACC */
            RRCA
            RRCA
            AND     11000000B               ; EN2,EN1,X,X,X,X,X,X (Motor2)
            LD      HL,PA_BUFF
            OR      (HL)                    ; Mix Motor2,Motor1
            LD      (HL),A                  ; EN2,EN1,D,C,B,A,EN2,EN1
            LD      A,B
            RRCA
            RRCA
            AND     0FH
            LD      (PB_BUFF),A             ; X,X,X,X,D,C,B,A (Motor2)
            LD      A,B
            RLCA                            ; Swap A
            RLCA
            RLCA
            RLCA
            AND     0F0H                    ; B,A,EN2,EN1,X,X,X,X (Motor3)
            LD      HL,PB_BUFF
            OR      (HL)                    ; Mix Mortor3,Motor2
            LD      (HL),A                  ; B,A,EN2,EN1,D,C,B,A
            LD      A,B
            RRCA
            RRCA
            RRCA
            RRCA
            AND     00000011B               ; X,X,X,X,X,X,D,C (Motor3)
            LD      (PC_BUFF),A
            LD      A,B
            RLCA
            RLCA
            AND     11111100B               ; D,C,B,A,EN2,EN1,X,X (Motor4)
            LD      HL,PC_BUFF
            OR      (HL)                    ; Mix Motor4 Motor3
            LD      (HL),A                  ; D,C,B,A,EN2,EN1,D,C
            ;
            LD      A,(PA_BUFF)             ; Out Signal
            OUT     (PA),A
            LD      A,(PB_BUFF)
            OUT     (PB),A
            LD      A,(PC_BUFF)
            OUT     (PC),A
            ;
            POP     HL                      ; Restore Register
            POP     DE
            POP     BC
            POP     AF
            RET

;/**********************/;
;/* Wave-Drive         */;
;/* Half Drive         */;
;/* ONE-Phase-ON Drive */;
;/* ONE-Excitation     */;
;/* 00,D,C,B,A,EN2,EN1 */;
;/* D7..............D0 */;
;/**********************/;
;
TAB_WAVE1:  DFB     00100010B               ; Step-2
            DFB     00000101B               ; Step-4
            DFB     00010010B               ; Step-6
            DFB     00001001B               ; Step-8
            DFB     00100010B               ; Step-2
            DFB     00000101B               ; Step-4
            DFB     00010010B               ; Step-6
            DFB     00001001B               ; Step-8
            ;
TAB_WAVE2:  DFB     00001001B               ; Step-8
            DFB     00010010B               ; Step-6
            DFB     00000101B               ; Step-4
            DFB     00100010B               ; Step-2
            DFB     00001001B               ; Step-8
            DFB     00010010B               ; Step-6
            DFB     00000101B               ; Step-4
            DFB     00100010B               ; Step-2

;/**********************/;
;/* Half Step Drive    */;
;/* ONE-TWO-Excitation */;
;/* 00,D,C,B,A,EN2,EN1 */;
;/* D7..............D0 */;
;/**********************/;
;
TAB_HALF1:  DFB     00101011B               ; Step-1
            DFB     00100010B               ; Step-2
            DFB     00100111B               ; Step-3
            DFB     00000101B               ; Step-4
            DFB     00010111B               ; Step-5
            DFB     00010010B               ; Step-6
            DFB     00011011B               ; Step-7
            DFB     00001001B               ; Step-8
            ;
TAB_HALF2:  DFB     00001001B               ; Step-8
            DFB     00011011B               ; Step-7
            DFB     00010010B               ; Step-6
            DFB     00010111B               ; Step-5
            DFB     00000101B               ; Step-4
            DFB     00100111B               ; Step-3
            DFB     00100010B               ; Step-2
            DFB     00101011B               ; Step-1
            
;/**********************/;
;/* TWO-Phase-ON Drive */;
;/* Normal-Drive       */;
;/* Full Step          */;
;/* TWO-Excitation     */;
;/* 00,D,C,B,A,EN2,EN1 */;
;/* D7..............D0 */;
;/**********************/;
;
TAB_FULL1:  DFB     00101011B               ; Step-1
            DFB     00100111B               ; Step-3
            DFB     00010111B               ; Step-5
            DFB     00011011B               ; Step-7
            DFB     00101011B               ; Step-1
            DFB     00100111B               ; Step-3
            DFB     00010111B               ; Step-5
            DFB     00011011B               ; Step-7
            ;
TAB_FULL2:  DFB     00011011B               ; Step-7
            DFB     00010111B               ; Step-5
            DFB     00100111B               ; Step-3
            DFB     00101011B               ; Step-1
            DFB     00011011B               ; Step-7
            DFB     00010111B               ; Step-5
            DFB     00100111B               ; Step-3
            DFB     00101011B               ; Step-1

;/**************/;
;/* Delay Time */;
;/**************/;
;
DELAY:      PUSH    AF
            PUSH    HL
            LD      HL,4000H
DEL1:       DEC     HL
            LD      A,H
            OR      L
            JR      NZ,DEL1
            POP     HL
            POP     AF
            RET

PA_BUFF:    DFS     1
PB_BUFF:    DFS     1
PC_BUFF:    DFS     1
STEP_CNT:   DFS     1
CYCLECNT:   DFS     1
STEP_INX:   DFS     1

            END

